.. Copyright (C) 2019 Tasos Alvas <tasos.alvas@qwertyuiopia.com>
.. Copyright (C) 2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _contribution_workflow:
.. include:: ../../DEVELOPMENT.rst
